<?php

namespace Litepie\Product\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Product\Http\Requests\ProductmodelRequest;
use Litepie\Product\Interfaces\ProductmodelRepositoryInterface;
use Litepie\Product\Models\Productmodel;
use Litepie\Product\Forms\Productmodel as Form;

/**
 * APIController  class for productmodel.
 */
class ProductmodelAPIController extends BaseController
{

    /**
     * Initialize productmodel resource controller.
     *
     * @param type ProductmodelRepositoryInterface $productmodel
     *
     * @return null
     */
    public function __construct(ProductmodelRepositoryInterface $productmodel)
    {
        parent::__construct();
        $this->repository = $productmodel;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Product\Repositories\Criteria\ProductmodelResourceCriteria::class);
    }

    /**
     * Display a list of productmodel.
     *
     * @return Response
     */
    public function index(ProductmodelRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Product\Repositories\Presenter\ProductmodelPresenter::class)
            ->paginate();
    }

    /**
     * Display productmodel.
     *
     * @param Request $request
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function show(ProductmodelRequest $request, Productmodel $productmodel)
    {
        return $productmodel->setPresenter(\Litepie\Product\Repositories\Presenter\ProductmodelListPresenter::class);
        ;
    }

    /**
     * Create new productmodel.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProductmodelRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('product::productmodel.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('product/productmodel/' . $productmodel->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('product/productmodel');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the productmodel.
     *
     * @param Request $request
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function update(ProductmodelRequest $request, Productmodel $productmodel)
    {
        try {
            $data = $request->all();

            $productmodel->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('product::productmodel.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('product/productmodel/' . $productmodel->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('product/productmodel/' . $productmodel->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the productmodel.
     *
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function destroy(ProductmodelRequest $request, Productmodel $productmodel)
    {
        try {
            $productmodel->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('product::productmodel.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('product/productmodel/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('product/productmodel/' . $productmodel->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
