<?php

namespace Litepie\Product\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Product\Interfaces\ProductmodelRepositoryInterface;

class ProductmodelPublicController extends BaseController
{
    // use ProductmodelWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Productmodel\Interfaces\ProductmodelRepositoryInterface $productmodel
     *
     * @return type
     */
    public function __construct(ProductmodelRepositoryInterface $productmodel)
    {
        $this->repository = $productmodel;
        parent::__construct();
    }

    /**
     * Show productmodel's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $productmodels = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('product::productmodel.names'))
            ->view('product::public.productmodel.index')
            ->data(compact('productmodels'))
            ->output();
    }


    /**
     * Show productmodel.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $productmodel = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($productmodel->name . trans('product::productmodel.name'))
            ->view('product::public.productmodel.show')
            ->data(compact('productmodel'))
            ->output();
    }

}
