<?php

namespace Litepie\Product\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Product\Models\Productmodel;

class ProductmodelPolicy
{

    /**
     * Determine if the given user can view the productmodel.
     *
     * @param UserPolicy $user
     * @param Productmodel $productmodel
     *
     * @return bool
     */
    public function view(UserPolicy $user, Productmodel $productmodel)
    {
        if ($user->canDo('product.productmodel.view') && $user->isAdmin()) {
            return true;
        }

        return $productmodel->user_id == user_id() && $productmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can create a productmodel.
     *
     * @param UserPolicy $user
     * @param Productmodel $productmodel
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('product.productmodel.create');
    }

    /**
     * Determine if the given user can update the given productmodel.
     *
     * @param UserPolicy $user
     * @param Productmodel $productmodel
     *
     * @return bool
     */
    public function update(UserPolicy $user, Productmodel $productmodel)
    {
        if ($user->canDo('product.productmodel.edit') && $user->isAdmin()) {
            return true;
        }

        return $productmodel->user_id == user_id() && $productmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given productmodel.
     *
     * @param UserPolicy $user
     * @param Productmodel $productmodel
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Productmodel $productmodel)
    {
        return $productmodel->user_id == user_id() && $productmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given productmodel.
     *
     * @param UserPolicy $user
     * @param Productmodel $productmodel
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Productmodel $productmodel)
    {
        if ($user->canDo('product.productmodel.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given productmodel.
     *
     * @param UserPolicy $user
     * @param Productmodel $productmodel
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Productmodel $productmodel)
    {
        if ($user->canDo('product.productmodel.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
